@@ -1,5 +1,5 @@
 package OpenTracing::WrapScope;
-our $VERSION = 'v0.104.1';
+our $VERSION = 'v0.105.0';
 use strict;
 use warnings;
 use warnings::register;
@@ -129,6 +129,8 @@ sub _load_sub_spec {
 
     my @subs;
     while (<$fh_subs>) {
+        next if /^\s*#/;    # commented-out line
+        s/\s*#.*\Z//;       # trailing comment
         chomp;
         croak "Unqualified subroutine: $_" if !/'|::/;
         push @subs, $_;
